@@ -475,9 +475,9 @@ static void ExitFatal(int err)
 /**
 **  Read header
 */
-static int ChkReadHeader(char *header, long *length)
+static int ChkReadHeader(char *header, int32_t *length)
 {
-	long len;
+	int32_t len;
 
 	if (chk_ptr >= chk_endptr) {
 		return 0;
@@ -536,13 +536,9 @@ static inline int ChkReadByte(void)
 static void ExtractMap(FILE *mpqfd, unsigned char **entry, int *size)
 {
 	int i;
-	unsigned long max;
-	int maxi;
 
 	*entry = NULL;
 	*size = 0;
-	max = 0;
-	maxi = 0;
 
 	for (i = 0; i < Mpq->FileCount; ++i) {
 		if (!strcmp("staredit\\scenario.chk", Mpq->FilenameTable + i * PATH_MAX)) {
@@ -552,7 +548,7 @@ static void ExtractMap(FILE *mpqfd, unsigned char **entry, int *size)
 			return;
 		}
 	}
-	fprintf(stderr, "Could not find staredit\\scenario.chk");
+	fprintf(stderr, "Could not find staredit\\scenario.chk\n");
 }
 
 /**
@@ -565,7 +561,7 @@ static void ExtractMap(FILE *mpqfd, unsigned char **entry, int *size)
 void LoadChkFromBuffer(unsigned char *chkdata, int len, WorldMap *map)
 {
 	char header[5];
-	long length;
+	int32_t length;
 
 	chk_ptr = (char *)chkdata;
 	chk_endptr = chk_ptr + len;
@@ -578,8 +574,7 @@ void LoadChkFromBuffer(unsigned char *chkdata, int len, WorldMap *map)
 		//
 		if (!memcmp(header, "VER ", 4)) {
 			if (length == 2) {
-				int v;
-				v = ChkReadWord();
+				ChkReadWord();
 				continue;
 			}
 			DebugLevel1("Wrong VER  length\n");
@@ -590,8 +585,7 @@ void LoadChkFromBuffer(unsigned char *chkdata, int len, WorldMap *map)
 		//
 		if (!memcmp(header, "IVER", 4)) {
 			if (length == 2) {
-				int v;
-				v = ChkReadWord();
+				ChkReadWord();
 				continue;
 			}
 			DebugLevel1("Wrong IVER length\n");
@@ -602,8 +596,7 @@ void LoadChkFromBuffer(unsigned char *chkdata, int len, WorldMap *map)
 		//
 		if (!memcmp(header, "IVE2", 4)) {
 			if (length == 2) {
-				int v;
-				v = ChkReadWord();
+				ChkReadWord();
 				continue;
 			}
 			DebugLevel1("Wrong IVE2 length\n");
@@ -882,20 +875,16 @@ void LoadChkFromBuffer(unsigned char *chkdata, int len, WorldMap *map)
 			if (length % 10 == 0) {
 				while (length > 0) {
 					int n;
-					int x;
-					int y;
-					int pl;
-					int fl;
 					char buf[30];
 //				    char **unit;
 //				    UnitType *type;
 
 					n = ChkReadWord();    // unit number of the thingy
-					x = ChkReadWord();    // x coordinate
-					y = ChkReadWord();    // y coordinate
-					pl = ChkReadByte();   // player number of owner
+					ChkReadWord();    // x coordinate
+					ChkReadWord();    // y coordinate
+					ChkReadByte();   // player number of owner
 					ChkReadByte();	// unknown
-					fl = ChkReadWord();   // flags
+					ChkReadWord();   // flags
 					length -= 10;
 
 					sprintf(buf, "%d", n);
@@ -1163,7 +1152,7 @@ void LoadChkFromBuffer(unsigned char *chkdata, int len, WorldMap *map)
 **  @param scm  Name of the scm file
 **  @param map  The map
 */
-void LoadScm(const char *scm, WorldMap *map)
+void LoadScm(const char *scm, WorldMap *map, const char *list)
 {
 	unsigned char *chkdata;
 	char buf[1024];
@@ -1179,7 +1168,7 @@ void LoadScm(const char *scm, WorldMap *map)
 		ExitFatal(-1);
 	}
 
-	if (Mpq->ReadInfo(fpMpq)) {
+	if (Mpq->ReadInfo(fpMpq, list)) {
 		fprintf(stderr, "MpqReadInfo failed\n");
 		ExitFatal(-1);
 	}
@@ -1475,10 +1464,10 @@ void FreeMap(WorldMap *map)
 	free(map->Tiles);
 }
 
-void ConvertScm(const char *scmname, const char *newname)
+void ConvertScm(const char *scmname, const char *newname, const char *list)
 {
 	WorldMap map;
-	LoadScm(scmname, &map);
+	LoadScm(scmname, &map, list);
 	SaveMap(newname, &map);
 	FreeMap(&map);
 }
@@ -1514,7 +1503,7 @@ int main(int argc, char **argv)
 	if (argc == 3) {
 		outdir = argv[2];
 	} else {
-		outdir = ".";
+		outdir = strdup(".");
 	}
 
 	if (strstr(infile, ".scm\0")) {
