@@ -39,7 +39,7 @@
 -------------------------------------------------------------------------------
 
 Name = "Stargus"
-Version = "2.2.6"
+Version = "2.2.7"
 Homepage = "https://launchpad.net/stargus"
 Licence = "GPL v2"
 Copyright = "Copyright (c) 1998-2012 by The Stratagus Project and Pali Rohar"
@@ -74,7 +74,7 @@ SetTitleScreens({
 --  Set the game name. It's used so we can mantain different savegames
 --  and setting. Might also be used for multiplayer.
 SetGameName("sc")
-
+SetFullGameName(Name)
 
 SetSelectionStyle("corners")
 Preference.ShowSightRange = false
@@ -200,6 +200,8 @@ DefineDefaultResourceAmounts(
   "minerals", 100000,
   "gas", 50000)
 
+DefineDefaultResourceMaxAmounts(-1, -1, -1, -1, -1, -1)
+  
 -------------------------------------------------------------------------------
 
 DefinePlayerColorIndex(8, 8)
